<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>ColorLabel</name>
    <message>
        <location filename="../colorLabel.cpp" line="37"/>
        <source>Click to change color.</source>
        <translation>Нажмите для изменения цвета.</translation>
    </message>
    <message>
        <location filename="../colorLabel.cpp" line="61"/>
        <source>Select Color</source>
        <translation>Выбрать цвет</translation>
    </message>
</context>
<context>
    <name>ConfigOtherToolKits</name>
    <message>
        <location filename="../configothertoolkits.cpp" line="178"/>
        <source>GTK themes</source>
        <translation>Темы GTK</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="179"/>
        <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
        <translation>&lt;p&gt;«%1» был перезаписан.&lt;/p&gt;&lt;p&gt;Копия прежних настроек находится в «%2»&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="244"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="244"/>
        <source>Error: gsettings cannot be run</source>
        <translation>Ошибка: gsettings не может быть запущен</translation>
    </message>
</context>
<context>
    <name>FontsConfig</name>
    <message>
        <location filename="../fontsconfig.ui" line="23"/>
        <source>Font</source>
        <translation>Шрифт</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="30"/>
        <source>Default font for user interface</source>
        <translation>Шрифт по умолчанию для пользовательского интерфейса</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="36"/>
        <source>Font name:</source>
        <translation>Название шрифта:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="46"/>
        <source>Style:</source>
        <translation>Стиль:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="77"/>
        <source>Point size:</source>
        <translation>Размер шрифта:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="54"/>
        <source>Normal</source>
        <translation>Нормальный</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="59"/>
        <source>Bold</source>
        <translation>Полужирный</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="64"/>
        <source>Italic</source>
        <translation>Наклонный</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="69"/>
        <source>Bold Italic</source>
        <translation>Полужирный наклонный</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="94"/>
        <source>The following settings only affect newly started applications</source>
        <translation>Настройки будут применены к вновь запущенным приложениям</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="100"/>
        <source>Use antialias fonts</source>
        <translation>Использовать сглаживание шрифтов</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="153"/>
        <source>Font hinting style:</source>
        <translation>Стиль хинтинга шрифта:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="118"/>
        <location filename="../fontsconfig.ui" line="164"/>
        <source>None</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="169"/>
        <source>Slight</source>
        <translation>Слабое</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="174"/>
        <source>Medium</source>
        <translation>Среднее</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="179"/>
        <source>Full</source>
        <translation>Полное</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="146"/>
        <source>Font hinting</source>
        <translation>Хинтинг шрифта</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="187"/>
        <source>Resolution (DPI):</source>
        <translation>Разрешение (DPI):</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="204"/>
        <source>Autohint</source>
        <translation>Автохинтинг</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="107"/>
        <source>Subpixel antialiasing:</source>
        <translation>Субпиксельное сглаживание:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="123"/>
        <source>RGB</source>
        <translation>RGB</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="128"/>
        <source>BGR</source>
        <translation>BGR</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="133"/>
        <source>VRGB</source>
        <translation>VRGB</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="138"/>
        <source>VBGR</source>
        <translation>VBGR</translation>
    </message>
</context>
<context>
    <name>GTKConfig</name>
    <message>
        <location filename="../gtkconfig.ui" line="44"/>
        <source>GTK Style</source>
        <translation>Стиль GTK</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="63"/>
        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
        <translation>Установить темы GTK (файлы настроек GTK перезапуштся)</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="93"/>
        <source>GTK 3 Theme</source>
        <translation>Тема GTK 3</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="77"/>
        <source>GTK 2 Theme</source>
        <translation>Тема GTK 2</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="103"/>
        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.

Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
        <translation>Чтобы добиться одинакового внешнего вида всех приложений, или выберите похожие стили/темы (по возможности) во всех списках, или выберите стиль &apos;gtk2&apos; для Qt (по возможности), дабы он имитировал тему GTK.

Удостоверьтесь, что «xsettingsd» установлен, чтобы GTK-приложения могли применять темы «на лету».</translation>
    </message>
</context>
<context>
    <name>IconThemeConfig</name>
    <message>
        <location filename="../iconthemeconfig.ui" line="14"/>
        <source>LXQt Appearance Configuration</source>
        <translation>Настройка внешнего вида LXQt</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="26"/>
        <source>Icons Theme</source>
        <translation>Тема значков</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="87"/>
        <source>The KDE extension of XDG icon themes -&gt; FollowsColorScheme</source>
        <translation>Расширение KDE тем значков XDG -&gt; FollowsColorScheme</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="90"/>
        <source>Colorize icons based on widget style (palette)</source>
        <translation>Цвет значков в соответствии с палитрой виджетов</translation>
    </message>
</context>
<context>
    <name>LXQtThemeConfig</name>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="23"/>
        <source>LXQt Theme</source>
        <translation>Тема LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="57"/>
        <source>Use wallpaper provided by theme</source>
        <translation>Использовать обои, предоставленные темой</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="64"/>
        <source>Use palette provided by theme</source>
        <translation>Использовать палитру, предоставленную темой</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.cpp" line="83"/>
        <source>(User Theme)</source>
        <translation>(Пользовательская тема)</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.cpp" line="185"/>
        <source>Open theme folder</source>
        <translation>Открыть каталог темы</translation>
    </message>
</context>
<context>
    <name>PalettesDialog</name>
    <message>
        <location filename="../palettes.ui" line="14"/>
        <location filename="../palettes.ui" line="20"/>
        <source>Palettes</source>
        <translation>Палитры</translation>
    </message>
    <message>
        <location filename="../palettes.ui" line="33"/>
        <source>Filter...</source>
        <translation>Фильтр...</translation>
    </message>
    <message>
        <location filename="../palettes.ui" line="43"/>
        <source>&amp;Remove</source>
        <translation>&amp;Удалить</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>LXQt Appearance Configuration</source>
        <translation>Настройка внешнего вида LXQt</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>Icons Theme</source>
        <translation>Тема иконок</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="92"/>
        <source>LXQt Theme</source>
        <translation>Тема LXQt</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="117"/>
        <source>GTK Style</source>
        <translation>Стиль GTK</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>Widget Style</source>
        <translation>Стиль виджетов</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="100"/>
        <source>Font</source>
        <translation>Шрифт</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="110"/>
        <source>Cursor</source>
        <translation>Курсор</translation>
    </message>
</context>
<context>
    <name>StyleConfig</name>
    <message>
        <location filename="../styleconfig.ui" line="33"/>
        <source>Widget Style</source>
        <translation>Стиль виджетов</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="63"/>
        <source>Qt Palette</source>
        <translation>Палитра Qt</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="77"/>
        <source>Some Qt styles may ignore these colors.</source>
        <translation>Некоторые стили Qt могут игнорировать эти цвета</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="102"/>
        <source>Window:</source>
        <translation>Окно:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="112"/>
        <source>View:</source>
        <translation>Обычный фон:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="122"/>
        <source>Selection:</source>
        <translation>Выделение:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="132"/>
        <source>Tooltip:</source>
        <translation>Всплывающая подсказка:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="146"/>
        <source>Link:</source>
        <translation>Ссылка:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="166"/>
        <source>Window Text:</source>
        <translation>Текст окна:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="176"/>
        <source>View Text:</source>
        <translation>Обычный текст:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="186"/>
        <source>Selected Text:</source>
        <translation>Выделенный текст:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="196"/>
        <source>Tooltip Text:</source>
        <translation>Текст всплывающей подсказки:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="210"/>
        <source>Visited Link:</source>
        <translation>Посещённая ссылка:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="242"/>
        <source>&amp;Save Palette</source>
        <translation>&amp;Сохранить палитру</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="249"/>
        <source>&amp;Load Palette</source>
        <translation>&amp;Загрузить палитру</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="269"/>
        <source>&amp;Default Palette</source>
        <translation>Палитра по &amp;умолчанию</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="284"/>
        <location filename="../styleconfig.ui" line="294"/>
        <location filename="../styleconfig.ui" line="326"/>
        <location filename="../styleconfig.ui" line="336"/>
        <location filename="../styleconfig.ui" line="368"/>
        <source>May be overridden by Qt style or app</source>
        <translation>Может быть переопределена стилем Qt или приложением</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="287"/>
        <source>Toolbar button style:</source>
        <translation>Стиль кнопок панели:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="298"/>
        <source>Only display the icon</source>
        <translation>Показывать только значок</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="303"/>
        <source>Only display the text</source>
        <translation>Показывать только текст</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="308"/>
        <source>The text appears beside the icon</source>
        <translation>Текст появляется сбоку от значка</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="313"/>
        <source>The text appears under the icon</source>
        <translation>Текст появляется под значком</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="318"/>
        <source>Default</source>
        <translation>По умолчанию</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="329"/>
        <source>Toolbar icon size:</source>
        <translation>Размер значков панели:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="340"/>
        <source>16</source>
        <translation>16</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="345"/>
        <source>22</source>
        <translation>22</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="350"/>
        <source>24</source>
        <translation>24</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="355"/>
        <source>32</source>
        <translation>32</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="360"/>
        <source>48</source>
        <translation>48</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="371"/>
        <source>Activate item on single click</source>
        <translation>Активировать элемент по одиночному щелчку мыши</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="51"/>
        <source>Qt Style</source>
        <translation>Стиль Qt</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="330"/>
        <location filename="../styleconfig.cpp" line="340"/>
        <source>Save Palette</source>
        <translation>Сохранить палитру</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="330"/>
        <source>Palette name:</source>
        <translation>Название палитры:</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="341"/>
        <source>A palette with the same name exists.
Do you want to replace it?</source>
        <translation>Палитра с таким названием существует.
Вы хотите заменить её?</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="484"/>
        <source>Remove Palettes</source>
        <translation>Удалить палитры</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="485"/>
        <source>Do you really want to remove selected palette(s)?
Root palettes will remain intact if existing.</source>
        <translation>Вы действительно хотите удалить выбранную(ые) палитру(ы)?
Корневые палитры останутся нетронутыми, если они существуют.</translation>
    </message>
</context>
</TS>
